"""Run ssh-run as a module with python -m ssh_run"""

import ssh_run.run

if __name__ == '__main__':
    ssh_run.run.main()
